Learn R Programming

drifter (version 0.2.1)

calculate_distance: Calculate Non-Intersection Distance

Description

Calculate Non-Intersection Distance

Usage

calculate_distance(variable_old, variable_new, bins = 20)

Arguments

.data

Dataframe.

dependent

Character vector of length 1: name of depdendent variable (must be numeric/continuous).

explanatory

Character vector of any length: name(s) of explanatory variables.

random_effect

Character vector of length 1, name of random effect variable.

factorlist

Option to provide output directly from summary_factorlist().

lmfit

Option to provide output directly from lmmulti() and lmmixed().

confint_type

For for lmer models, one of c("default", "Wald", "profile", "boot") Note "default" == "Wald".

breaks

Manually specify x-axis breaks in format c(0.1, 1, 10).

column_space

Adjust table column spacing.

dependent_label

Main label for plot.

prefix

Plots are titled by default with the dependent variable. This adds text before that label.

suffix

Plots are titled with the dependent variable. This adds text after that label.

table_text_size

Alter font size of table text.

title_text_size

Alter font size of title text.

plot_opts

A list of arguments to be appended to the ggplot call by "+".

table_opts

A list of arguments to be appended to the ggplot table call by "+".

...

Other parameters.

variable_old

variable from `old` data

variable_new

variable from `new` data

bins

continuous variables are discretized to `bins` intervals of equal size

Value

Non-Intersection Distance

Examples

Run this code
# NOT RUN {
calculate_distance(rnorm(1000), rnorm(1000))
calculate_distance(rnorm(1000), runif(1000))
# }

Run the code above in your browser using DataLab