powered by
Calculate Non-Intersection Distance
calculate_distance(variable_old, variable_new, bins = 20)
Dataframe.
Character vector of length 1: name of depdendent variable (must be numeric/continuous).
Character vector of any length: name(s) of explanatory variables.
Character vector of length 1, name of random effect variable.
Option to provide output directly from summary_factorlist().
summary_factorlist()
Option to provide output directly from lmmulti() and lmmixed().
lmmulti()
lmmixed()
For for lmer models, one of c("default", "Wald", "profile", "boot") Note "default" == "Wald".
lmer
c("default", "Wald", "profile", "boot")
Manually specify x-axis breaks in format c(0.1, 1, 10).
c(0.1, 1, 10)
Adjust table column spacing.
Main label for plot.
Plots are titled by default with the dependent variable. This adds text before that label.
Plots are titled with the dependent variable. This adds text after that label.
Alter font size of table text.
Alter font size of title text.
A list of arguments to be appended to the ggplot call by "+".
A list of arguments to be appended to the ggplot table call by "+".
Other parameters.
variable from `old` data
variable from `new` data
continuous variables are discretized to `bins` intervals of equal size
Non-Intersection Distance
# NOT RUN { calculate_distance(rnorm(1000), rnorm(1000)) calculate_distance(rnorm(1000), runif(1000)) # }
Run the code above in your browser using DataLab